# Step 2: Scope Applications
### On this page
  * [Identify Applications](https://help.sap.com/docs/leanix/ea/application-rationalization-scope-applications#identify-applications)
  * [Save Results](https://help.sap.com/docs/leanix/ea/application-rationalization-scope-applications#save-results)
  * [Add Fact Sheet Owners](https://help.sap.com/docs/leanix/ea/application-rationalization-scope-applications#add-fact-sheet-owners)
  * [Tag Scoped Applications](https://help.sap.com/docs/leanix/ea/application-rationalization-scope-applications#tag-scoped-applications)


Focus your application rationalization efforts by scoping applications and bring in stakeholders for collaborative assessment.
Assessing the rationalization potential of your application portfolio can be a large initiative, especially if your IT landscape contains hundreds of applications. To make the process more manageable, scope your applications to work with a digestible group.
There are different approaches to scoping that can also be combined:
  * Focus on specific business capabilities or organizations
  * Exclude applications that will soon be retired
  * Focus on applications that require action as outlined in the IT strategy
